@@ -37,9 +37,9 @@ use SNMP::Info;
 @SNMP::Info::CiscoConfig::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CiscoConfig::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = (
     'CISCO-CONFIG-COPY-MIB' => 'ccCopyTable',
@@ -97,6 +97,10 @@ sub copy_run_tftp {
         print "Using new method, row iid: $rand\n" if $ciscoconfig->debug();
 
         #Check each set, delete created row if any fail
+        unless ( $ciscoconfig->set_config_row_status( 5, $rand ) ) {
+            $ciscoconfig->error_throw("Initializing config copy instruction failed");
+            return;
+        }
         unless ( $ciscoconfig->set_config_source_type( 4, $rand ) ) {
             $ciscoconfig->error_throw("Setting source type failed");
             unless ( $ciscoconfig->set_config_row_status( 6, $rand ) ) {
@@ -275,7 +279,7 @@ Justin Hunter, Eric Miller
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
 
     or die "Can't connect to DestHost.\n";
 
@@ -332,10 +336,6 @@ These are methods that return scalar value from SNMP
 These are methods that return tables of information in the form of a reference
 to a hash.
 
-=over
-
-=back
-
 =head2 Config Copy Request Table  (C<ccCopyTable>)
 
 =over
@@ -431,7 +431,7 @@ Table of Flash copy operation entries.
 These are methods that provide SNMP set functionality for overridden methods
 or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
-operations. 
+operations.
 
 =over
 
@@ -448,7 +448,7 @@ older procedure has been depreciated by Cisco and is utilized only to support
 devices running older code revisions.
 
  Example:
- $ciscoconfig->copy_run_tftp('1.2.3.4', 'myconfig') 
+ $ciscoconfig->copy_run_tftp('1.2.3.4', 'myconfig')
     or die "Couldn't save config. ",$ciscoconfig->error(1);
 
 =item $ciscoconfig->copy_run_start()
