@@ -32,13 +32,14 @@ package SNMP::Info::IEEE802dot11;
 
 use strict;
 use Exporter;
+use SNMP::Info;
 
-@SNMP::Info::IEEE802dot11::ISA       = qw/Exporter/;
+@SNMP::Info::IEEE802dot11::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::IEEE802dot11::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 %MIBS = ( 'IEEE802dot11-MIB' => 'dot11DesiredSSID', );
 
@@ -202,7 +203,7 @@ Eric Miller
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
 
     or die "Can't connect to DestHost.\n";
 
