@@ -1,7 +1,7 @@
 # SNMP::Info::LLDP
 # $Id$
 #
-# Copyright (c) 2008 Eric Miller
+# Copyright (c) 2018 Eric Miller
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@ use SNMP::Info;
 @SNMP::Info::LLDP::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::LLDP::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 %MIBS = (
     'LLDP-MIB'          => 'lldpLocSysCapEnabled',
@@ -116,7 +116,8 @@ sub hasLLDP {
     my $lldp_cap = $lldp->lldp_sys_cap();
     return 1 if defined $lldp_cap;
 
-    # If the device doesn't return local system capabilities, fallback by checking if it would report neighbors
+    # If the device doesn't return local system capabilities, fallback
+    # by checking if it would report neighbors
     my $lldp_rem = $lldp->lldp_rem_id() || {};
     return 1 if scalar keys %$lldp_rem;
 
@@ -138,13 +139,18 @@ sub lldp_if {
         my @aOID = split( '\.', $key );
         my $port = $aOID[1];
         next unless $port;
-        # Local LLDP port may not equate to ifIndex, see LldpPortNumber TEXTUAL-CONVENTION in LLDP-MIB.
-        # Cross reference lldpLocPortDesc with ifDescr and ifAlias to get ifIndex,
-        # prefer ifDescr over ifAlias because using cross ref with description is correct behavior 
-        # according to the LLDP-MIB. Some devices (eg H3C gear) seem to use ifAlias though.
+
+        # Local LLDP port may not equate to ifIndex, see LldpPortNumber
+        # TEXTUAL-CONVENTION in LLDP-MIB. Cross reference lldpLocPortDesc
+        # with ifDescr and ifAlias to get ifIndex, prefer ifDescr over
+        # ifAlias because using cross ref with description is correct
+        # behavior according to the LLDP-MIB. Some devices (eg H3C gear)
+        # seem to use ifAlias though.
         my $lldp_desc = $lldp->lldpLocPortDesc($port);
         my $desc      = $lldp_desc->{$port};
-        # If cross reference is successful use it, otherwise stick with lldpRemLocalPortNum
+
+        # If cross reference is successful use it, otherwise stick with
+        # lldpRemLocalPortNum
         if ( $desc && exists $r_i_descr{$desc} ) {
             $port = $r_i_descr{$desc};
         }
@@ -165,7 +171,7 @@ sub lldp_ip {
 
     my %lldp_ip;
     foreach my $key ( keys %$rman_addr ) {
-        my ( $index, $proto, $addr ) = _lldp_addr_index($key);
+        my ( $index, $proto, $addr ) = $lldp->_lldp_addr_index($key);
         next unless defined $index;
         next unless $proto == 1;
         $lldp_ip{$index} = $addr;
@@ -181,7 +187,7 @@ sub lldp_ipv6 {
 
     my %lldp_ipv6;
     foreach my $key ( keys %$rman_addr ) {
-        my ( $index, $proto, $addr ) = _lldp_addr_index($key);
+        my ( $index, $proto, $addr ) = $lldp->_lldp_addr_index($key);
         next unless defined $index;
         next unless $proto == 2;
         $lldp_ipv6{$index} = $addr;
@@ -197,7 +203,7 @@ sub lldp_mac {
 
     my %lldp_ipv6;
     foreach my $key ( keys %$rman_addr ) {
-        my ( $index, $proto, $addr ) = _lldp_addr_index($key);
+        my ( $index, $proto, $addr ) = $lldp->_lldp_addr_index($key);
         next unless defined $index;
         next unless $proto == 6;
         $lldp_ipv6{$index} = $addr;
@@ -213,7 +219,7 @@ sub lldp_addr {
 
     my %lldp_ip;
     foreach my $key ( keys %$rman_addr ) {
-        my ( $index, $proto, $addr ) = _lldp_addr_index($key);
+        my ( $index, $proto, $addr ) = $lldp->_lldp_addr_index($key);
         next unless defined $index;
         $lldp_ip{$index} = $addr;
     }
@@ -233,7 +239,10 @@ sub lldp_port {
     foreach my $key ( sort keys %$pid ) {
         my $port = $pdesc->{$key};
         my $type = $ptype->{$key};
-        if ( $type and $type eq 'interfaceName' ) {
+        if (    $type
+            and ( $type eq 'interfaceName' or $type eq 'local' )
+            and ( defined $pid->{$key} and $pid->{$key} !~ /^\d+$/ ) )
+        {
 
             # If the pid claims to be an interface name,
             # believe it.
@@ -246,8 +255,7 @@ sub lldp_port {
 
           # May need to format other types in the future, i.e. Network address
             if ( $type =~ /mac/ ) {
-                $port = join( ':',
-                    map { sprintf "%02x", $_ } unpack( 'C*', $port ) );
+                $port = SNMP::Info::munge_mac($port)
             }
         }
 
@@ -282,12 +290,13 @@ sub lldp_id {
 
         # May need to format other types in the future
         if ( $type =~ /mac/ ) {
-            $id = join( ':', map { sprintf "%02x", $_ } unpack( 'C*', $id ) );
+            $id = SNMP::Info::munge_mac($id)
         }
         elsif ( $type eq 'networkAddress' ) {
             if ( length( unpack( 'H*', $id ) ) == 10 ) {
 
-                # IP address (first octet is sign, I guess)
+                # IP address - first octet is IANA Address Family Number, need
+                # walk with IPv6
                 my @octets
                     = ( map { sprintf "%02x", $_ } unpack( 'C*', $id ) )
                     [ 1 .. 4 ];
@@ -323,7 +332,8 @@ sub lldp_cap {
     # Encoded as BITS which Perl Net-SNMP implementation doesn't seem to
     # be able to enumerate for us, so we have to get it from the MIB
     # and enumerate ourselves
-    my $oid = SNMP::translateObj( 'lldpRemSysCapEnabled', 0, 1 ) || '';
+    my $oid
+        = SNMP::translateObj( 'LLDP-MIB::lldpRemSysCapEnabled', 0, 1 ) || '';
     my $enums = (
         ( ref {} eq ref $SNMP::MIB{$oid}{'enums'} )
         ? $SNMP::MIB{$oid}{'enums'}
@@ -401,11 +411,13 @@ sub lldp_media_cap {
 # Break up the lldpRemManAddrTable INDEX into common index, protocol,
 # and address.
 sub _lldp_addr_index {
-    my $idx    = shift;
-    my @oids   = split( /\./, $idx );
-    my $index  = join( '.', splice( @oids, 0, 3 ) );
-    my $proto  = shift(@oids);
-    shift(@oids) if scalar @oids > 4; # $length
+    my $lldp = shift;
+    my $idx  = shift;
+
+    my @oids = split( /\./, $idx );
+    my $index = join( '.', splice( @oids, 0, 3 ) );
+    my $proto = shift(@oids);
+    shift(@oids) if scalar @oids > 4;    # $length
 
     # IPv4
     if ( $proto == 1 ) {
@@ -415,7 +427,7 @@ sub _lldp_addr_index {
     # IPv6
     elsif ( $proto == 2 ) {
         return ( $index, $proto,
-            join(':', unpack('(H4)*', pack('C*', @oids)) ) );
+            join( ':', unpack( '(H4)*', pack( 'C*', @oids ) ) ) );
     }
 
     # MAC
@@ -443,10 +455,10 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- my $lldp = new SNMP::Info ( 
+ my $lldp = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'router', 
+                             DestHost    => 'router',
                              Community   => 'public',
                              Version     => 2
                            );
@@ -472,7 +484,7 @@ Eric Miller
 
 =head1 DESCRIPTION
 
-SNMP::Info::LLDP is a subclass of SNMP::Info that provides an object oriented 
+SNMP::Info::LLDP is a subclass of SNMP::Info that provides an object oriented
 interface to LLDP information through SNMP.
 
 LLDP is a Layer 2 protocol that allows a network device to advertise its
@@ -508,7 +520,7 @@ These are methods that return scalar values from SNMP
 
 =item $lldp->hasLLDP()
 
-Is LLDP is active in this device?  
+Is LLDP is active in this device?
 
 Note:  LLDP may be active, but nothing in C<lldpRemoteSystemsData> Tables so
 the device would not return any useful topology information.
@@ -519,7 +531,7 @@ The string value used to identify the system name of the local system.  If the
 local agent supports IETF RFC 3418, C<lldpLocSysName> object should have the
 same value of C<sysName> object.
 
-Nulls are removed before the value is returned. 
+Nulls are removed before the value is returned.
 
 (C<lldpLocSysName>)
 
@@ -533,7 +545,7 @@ Nulls are removed before the value is returned.
 
 (C<lldpLocSysDesc>)
 
-=item  $lldp->lldp_sys_cap() 
+=item  $lldp->lldp_sys_cap()
 
 Returns which system capabilities are enabled on the local system.  Results
 are munged into an ascii binary string, LSB.  Each digit represents a bit
@@ -583,8 +595,8 @@ with the remote system.
 
 =item $lldp->lldp_if()
 
-Returns the mapping to the SNMP Interface Table. Tries to cross reference 
-(C<lldpLocPortDesc>) with (C<ifDescr>) and (C<ifAlias>) to get (C<ifIndex>), 
+Returns the mapping to the SNMP Interface Table. Tries to cross reference
+(C<lldpLocPortDesc>) with (C<ifDescr>) and (C<ifAlias>) to get (C<ifIndex>),
 if unable defaults to (C<lldpRemLocalPortNum>).
 
 =item  $lldp->lldp_ip()
@@ -599,7 +611,7 @@ use lldp_addr if you don't care about return address type.
 
 =item  $lldp->lldp_mac()
 
-Returns remote (management) MAC address, if known.  Returns for all other 
+Returns remote (management) MAC address, if known.  Returns for all other
 address types, use lldp_addr if you don't care about return address type.
 
 =item  $lldp->lldp_addr()
@@ -620,13 +632,13 @@ Returns remote port ID
 Tries to return something useful from C<lldp_rem_sysdesc()> or
 C<lldp_rem_sysname()>.
 
-=item  $lldp->lldp_cap() 
+=item  $lldp->lldp_cap()
 
 Returns hash of arrays with each array containing the system capabilities
 supported by the remote system.  Possible elements in the array are
 enumerated from C<LldpSystemCapabilitiesMap>.
 
-=item  $lldp->lldp_media_cap() 
+=item  $lldp->lldp_media_cap()
 
 Returns hash of arrays with each array containing the media capabilities
 supported by the remote system.  Possible elements in the array are
@@ -671,7 +683,7 @@ the remote system.
 Returns the string value used to identify the description of the given port
 associated with the remote system.
 
-Nulls are removed before the value is returned. 
+Nulls are removed before the value is returned.
 
 (C<lldpRemPortDesc>)
 
@@ -680,7 +692,7 @@ Nulls are removed before the value is returned.
 Returns the string value used to identify the system name of the remote
 system.
 
-Nulls are removed before the value is returned. 
+Nulls are removed before the value is returned.
 
 (C<lldpRemSysName>)
 
@@ -689,70 +701,70 @@ Nulls are removed before the value is returned.
 Returns the string value used to identify the system description of the
 remote system.
 
-Nulls are removed before the value is returned. 
+Nulls are removed before the value is returned.
 
 (C<lldpRemSysDesc>)
 
 =item $lldp->lldp_rem_hw_rev()
 
 Returns the string value used to identify the hardware revision of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemHardwareRev>)
 
 =item $lldp->lldp_rem_fw_rev()
 
 Returns the string value used to identify the firmware revision of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemHardwareRev>)
 
 =item $lldp->lldp_rem_sw_rev()
 
 Returns the string value used to identify the software revision of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemSoftwareRev>)
 
 =item $lldp->lldp_rem_serial()
 
 Returns the string value used to identify the serial number of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemSerialNum>)
 
 =item $lldp->lldp_rem_vendor()
 
 Returns the string value used to identify the manufacturer of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemMfgName>)
 
 =item $lldp->lldp_rem_asset()
 
 Returns the string value used to identify the asset number of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemAssetID>)
 
 =item $lldp->lldp_rem_model()
 
 Returns the string value used to identify the model of the
-remote system. Nulls are removed before the value is returned. 
+remote system. Nulls are removed before the value is returned.
 
 (C<lldpXMedRemModelName>)
 
-=item  $lldp->lldp_rem_media_cap_spt() 
+=item  $lldp->lldp_rem_media_cap_spt()
 
 Returns which media capabilities are supported on the remote system. Results
 are munged into an ascii binary string, LSB.
 
-=item  $lldp->lldp_rem_media_cap() 
+=item  $lldp->lldp_rem_media_cap()
 
 Returns which media capabilities are enabled on the remote system. Results
 are munged into an ascii binary string, LSB.
 
-=item  $lldp->lldp_rem_sys_cap() 
+=item  $lldp->lldp_rem_sys_cap()
 
 Returns which system capabilities are enabled on the remote system.  Results
 are munged into an ascii binary string, LSB.  Each digit represents a bit
