@@ -1,3 +1,31 @@
+# SNMP::Info::Layer2::Adtran - SNMP Interface to Adtran Devices
+#
+# Copyright (c) 2019 by The Netdisco Developer Team.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+#     * Redistributions of source code must retain the above copyright notice,
+#       this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name of the University of California, Santa Cruz nor the
+#       names of its contributors may be used to endorse or promote products
+#       derived from this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+# LIABLE FOR # ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+
 package SNMP::Info::Layer2::Adtran;
 
 use strict;
@@ -9,27 +37,27 @@ use SNMP::Info::Layer3;
 @SNMP::Info::Layer2::Adtran::ISA       = qw/SNMP::Info::LLDP SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::Adtran::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 # This will be filled in with the device's index into the EntPhysicalEntry
 # table by the serial() function.
 our $index = undef;
 
-%MIBS = ( 
+%MIBS = (
     %SNMP::Info::Layer2::MIBS,
     %SNMP::Info::Layer3::MIBS,
-    'ADTRAN-GENEVC-MIB'     => 'adGenEVCMIB',
-    'ADTRAN-GENMEF-MIB'     => 'adGenMEFMIB',
-    'ADTRAN-GENPORT-MIB'    => 'adGenPort',
+#    'ADTRAN-GENEVC-MIB'     => 'adGenEVCMIB',
+#    'ADTRAN-GENMEF-MIB'     => 'adGenMEFMIB',
+#    'ADTRAN-GENPORT-MIB'    => 'adGenPort',
     'ADTRAN-MIB'            => 'adtran',
     'ADTRAN-AOSUNIT'     => 'adGenAOSUnitMib',
- );
+);
 
 %GLOBALS = (
-    %SNMP::Info::Layer2::GLOBALS, 
-    %SNMP::Info::Layer3::GLOBALS, 
+    %SNMP::Info::Layer2::GLOBALS,
+    %SNMP::Info::Layer3::GLOBALS,
     %SNMP::Info::LLDP::GLOBALS,
     'serial'    => 'adProdSerialNumber',
     'ad_mgmtevcvid' => 'adGenEVCSysMgmtEVCSTagVID',
@@ -37,7 +65,7 @@ our $index = undef;
 
 %FUNCS = ( %SNMP::Info::Layer2::FUNCS,
            %SNMP::Info::Layer3::FUNCS,
-           %SNMP::Info::LLDP::FUNCS, 
+           %SNMP::Info::LLDP::FUNCS,
            'ad_evcstag' => 'adGenEVCLookupName',
            'ad_menport' => 'adGenMenPortRowStatus',
            'ad_evcnamevid' => 'adGenEVCSTagVID',
@@ -58,11 +86,11 @@ sub os {
 
 sub layers {
     my $adtran = shift;
-    
+
     my $layers = $adtran->SUPER::layers();
-    # Some netvantas don't report L2 properly 
+    # Some netvantas don't report L2 properly
     my $macs   = $adtran->fw_mac();
-    
+
     if (keys %$macs) {
         my $l = substr $layers, 6, 1, "1";
     }
@@ -77,7 +105,7 @@ sub os_ver {
     my $aos_ver = $adtran->adAOSDeviceVersion();
     return $aos_ver;
 }
-sub model { 
+sub model {
     my $adtran = shift;
     my $id = $adtran->id();
     my $mod = $adtran->adProdName() || undef;
@@ -85,7 +113,7 @@ sub model {
     my $model = $adtran->adAOSDeviceProductName() || undef;
     return $model;
 }
-sub serial { 
+sub serial {
     my $adtran = shift;
     my $e_serial = $adtran->e_serial() || {};
     my $serial2 = $e_serial->{1} || undef;
@@ -96,19 +124,19 @@ sub serial {
 sub i_name {
     my $adtran = shift;
     my $partial = shift;
-    my $i_name = $adtran->SUPER::i_alias() || undef; 
+    my $i_name = $adtran->SUPER::i_alias() || undef;
     return $i_name if (defined $i_name);
     $i_name = {};
     my $adname = $adtran->ad_genportcustuse() || undef;
-    if (defined $adname) {  
-        foreach my $port (keys %$adname) { 
+    if (defined $adname) {
+        foreach my $port (keys %$adname) {
             my @split = split(/\./,$port);
             $i_name->{@split[1]} = $adname->{$port};
         }
     }
     return $i_name;
 }
-sub i_vlan { 
+sub i_vlan {
     my $adtran = shift;
     my $partial = shift;
     my $uniports = $adtran->ad_evcmapuniport() || undef;
@@ -127,14 +155,14 @@ sub i_vlan {
         return $i_vlan;
     }
     return {};
-        
+
 }
-        
-sub i_vlan_membership {         
+
+sub i_vlan_membership {
     my $adtran  = shift;
     my $partial = shift;
     my $i_vlan = $adtran->ad_menport();
-    if (defined $i_vlan) { 
+    if (defined $i_vlan) {
         my $vlans = {};
         my $v_name = $adtran->v_name();
         foreach my $vid (keys %$v_name) {
@@ -174,14 +202,14 @@ SNMP::Info::Layer2::Adtran - SNMP Interface to Adtran Devices
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $adtran = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $adtran->class();
