@@ -47,9 +47,9 @@ use SNMP::Info::IEEE802dot11;
     SNMP::Info::CiscoStats SNMP::Info::CiscoConfig SNMP::Info::CDP Exporter/;
 @SNMP::Info::Layer2::Aironet::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 %GLOBALS = (
     %SNMP::Info::IEEE802dot11::GLOBALS,
@@ -60,7 +60,6 @@ $VERSION = '3.53';
     %SNMP::Info::CiscoConfig::GLOBALS,
     %SNMP::Info::CDP::GLOBALS,
     'serial' => 'entPhysicalSerialNum.1',
-    'descr'  => 'sysDescr',
     'ps1_type' => 'cpoePdCurrentPowerSource'
 );
 
@@ -136,7 +135,7 @@ sub interfaces {
 # Tag on e_descr.1
 sub description {
     my $aironet = shift;
-    my $descr   = $aironet->descr();
+    my $descr   = $aironet->SUPER::description();
     my $e_descr = $aironet->e_descr();
 
     $descr = "$e_descr->{1}  $descr" if defined $e_descr->{1};
@@ -444,7 +443,7 @@ sub i_ssidmac {
     my $partial    = shift;
     my $mbss_mac_addr = $aironet->mbss_mac_addr();
 
-    # Same logic as i_ssidbcast to return same indexes as i_ssidlist 
+    # Same logic as i_ssidbcast to return same indexes as i_ssidlist
     my $map = {};
     foreach my $key ( keys %$mbss_mac_addr ) {
         my ( $interface, @idx ) = split( /\./, $key );
@@ -485,14 +484,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $aironet = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $aironet->class();
@@ -518,7 +517,7 @@ This class is for devices running Cisco IOS software (newer)
 =back
 
 For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
+after determining a more specific class using the method above.
 
 my $aironet = new SNMP::Info::Layer2::Aironet(...);
 
@@ -656,11 +655,11 @@ being broadcast.
 =item $aironet->i_ssidmac()
 
 With the same keys as i_ssidlist, returns the Basic service set
-identification (BSSID), MAC address, the AP is using for the SSID. 
+identification (BSSID), MAC address, the AP is using for the SSID.
 
 =item $aironet ps1_status()
 
-Returns the PoE injector status based on C<cpoePdSupportedPower> and 
+Returns the PoE injector status based on C<cpoePdSupportedPower> and
 C<cpoePdSupportedPowerMode>.
 
 =back
