@@ -38,9 +38,9 @@ use SNMP::Info::Layer1;
 @SNMP::Info::Layer2::Allied::ISA       = qw/SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::Allied::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 %GLOBALS = ( %SNMP::Info::Layer2::GLOBALS );
 
@@ -73,6 +73,7 @@ sub os_ver {
     if ( $descr =~ m/version (\d+\.\d+)/ ) {
         return $1;
     }
+    return;
 }
 
 sub model {
@@ -137,14 +138,14 @@ Max Baker, Dmitry Sergienko <dmitry@trifle.net>
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $allied = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myhub',
                           Community   => 'public',
                           Version     => 1
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $allied->class();
@@ -152,8 +153,8 @@ Max Baker, Dmitry Sergienko <dmitry@trifle.net>
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
-Allied device through SNMP. See inherited classes' documentation for 
+Provides abstraction to the configuration information obtainable from a
+Allied device through SNMP. See inherited classes' documentation for
 inherited methods.
 
 =head2 Inherited Classes
@@ -194,7 +195,7 @@ Returns 'allied' :)
 
 =item $allied->os()
 
-Returns 'allied' 
+Returns 'allied'
 
 =item $allied->os_ver()
 
@@ -212,7 +213,7 @@ Tries to cull out C<AT-nnnnX> out of the description field.
 
 =item $allied->mac()
 
-Returns device MAC. 
+Returns device MAC.
 
 =back
 
