@@ -40,9 +40,9 @@ use SNMP::Info::Layer2::Cisco;
     = qw/SNMP::Info::CiscoStack SNMP::Info::Layer2::Cisco Exporter/;
 @SNMP::Info::Layer2::Catalyst::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = (
     %SNMP::Info::Layer2::Cisco::MIBS,
@@ -70,7 +70,7 @@ $VERSION = '3.34';
 sub i_physical {
     my $cat = shift;
 
-    my $p_port = $cat->p_port();
+    my $p_port = $cat->p_port() || {};
 
     my %i_physical;
     foreach my $port ( keys %$p_port ) {
@@ -104,8 +104,8 @@ sub os_ver {
 # Workaround for incomplete bp_index
 sub bp_index {
     my $cat     = shift;
-    my $p_index = $cat->p_port();
-    my $b_index = $cat->p_oidx();
+    my $p_index = $cat->p_port() || {};
+    my $b_index = $cat->p_oidx() || {};
 
     my %bp_index;
     foreach my $iid ( keys %$p_index ) {
@@ -173,14 +173,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $cat = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $cat->class();
@@ -206,7 +206,7 @@ Note:  Some older Catalyst switches will only talk SNMP version 1.  Some
 newer ones will not return all their data if connected via Version 1.
 
 For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
+after determining a more specific class using the method above.
 
  my $cat = new SNMP::Info::Layer2::Catalyst(...);
 
@@ -246,7 +246,7 @@ Returns 'catalyst'
 
 =item $cat->os_ver()
 
-Tries to use the value from SNMP::Info::CiscoStats->os_ver() and if it fails 
+Tries to use the value from SNMP::Info::CiscoStats->os_ver() and if it fails
 it grabs $cat->m_swver()->{1} and uses that.
 
 =item $cat->vendor()
@@ -279,11 +279,11 @@ to a hash.
 =item $cat->interfaces()
 
 Returns the map between SNMP Interface Identifier (iid) and physical port
-name. 
+name.
 
 =item $cat->i_name()
 
-Returns reference to hash of iid to human set name. 
+Returns reference to hash of iid to human set name.
 
 C<portName>
 
