@@ -34,9 +34,9 @@ use SNMP::Info::Layer2;
 @SNMP::Info::Layer2::Kentrox::ISA       = qw/SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::Kentrox::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE $AUTOLOAD/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE, $AUTOLOAD);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS,
@@ -66,6 +66,7 @@ sub os_ver {
     if ( $descr =~ /^\S+\s\S+\s\S+\s(\S+)/){
         return $1;
     }
+    return;
 }
 
 sub serial {
@@ -75,7 +76,7 @@ sub serial {
         my $str = substr($1,8,10);
         return $str;
     }
-
+    return;
 }
 sub vendor {
     return 'Kentrox';
@@ -87,6 +88,7 @@ sub model {
     if ( $descr =~ /^(\S+\s\S+)/){
         return $1;
     }
+    return;
 }
 
 1;
@@ -166,12 +168,6 @@ See documentation in L<SNMP::Info::Layer2/"GLOBALS"> for details.
 These are methods that return tables of information in the form of a reference
 to a hash.
 
-=head2 Overrides
-
-=over
-
-=back
-
 =head2 Table Methods imported from SNMP::Info::Layer2
 
 See documentation in L<SNMP::Info::Layer2/"TABLE METHODS"> for details.
