@@ -53,9 +53,9 @@ use SNMP::Info::Layer3;
     Exporter/;
 @SNMP::Info::Layer3::Cisco::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.68';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -97,22 +97,18 @@ $VERSION = '3.53';
     %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::CiscoVTP::FUNCS,
 
-    # EIGRP
-    'eigrp_peers' => 'cEigrpPeerAddr',
+    # CISCO-EIGRP-MIB::cEigrpPeerTable
+    'c_eigrp_peer_types' => 'cEigrpPeerAddrType',
+    'c_eigrp_peers'      => 'cEigrpPeerAddr',
+
 );
 
 %MUNGE = (
-    %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::CiscoStpExtensions::MUNGE,
-    %SNMP::Info::CiscoPower::MUNGE,
-    %SNMP::Info::CiscoConfig::MUNGE,
-    %SNMP::Info::CiscoQOS::MUNGE,
-    %SNMP::Info::CiscoRTT::MUNGE,
-    %SNMP::Info::CiscoStats::MUNGE,
-    %SNMP::Info::CDP::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
-    %SNMP::Info::CiscoVTP::MUNGE,
-    'eigrp_peers' => \&SNMP::Info::munge_ip,
+    %SNMP::Info::Layer3::MUNGE,     %SNMP::Info::CiscoStpExtensions::MUNGE,
+    %SNMP::Info::CiscoPower::MUNGE, %SNMP::Info::CiscoConfig::MUNGE,
+    %SNMP::Info::CiscoQOS::MUNGE,   %SNMP::Info::CiscoRTT::MUNGE,
+    %SNMP::Info::CiscoStats::MUNGE, %SNMP::Info::CDP::MUNGE,
+    %SNMP::Info::LLDP::MUNGE,       %SNMP::Info::CiscoVTP::MUNGE,
 );
 
 sub i_vlan {
@@ -128,19 +124,53 @@ sub i_vlan {
         if (   $i_type->{$idx} eq 'l2vlan'
             || $i_type->{$idx} eq '135' && !defined $i_vlan->{$idx} )
         {
+            # Not sure where this regex came from, anchored at end?
             if ( $i_descr->{$idx} =~ /\.(\d+)$/ ) {
                 $i_vlan->{$idx} = $1;
             }
+
+            # This matches 101 in 'Ethernet0.101-802.1Q vLAN subif'
+            elsif ( $i_descr->{$idx} =~ /\.(\d+)-/ ) {
+                $i_vlan->{$idx} = $1;
+            }
         }
     }
     return $i_vlan;
 }
 
-sub cisco_comm_indexing { 
+sub cisco_comm_indexing {
     my $cisco = shift;
-    # If we get a VTP version, it's *extremely* likely that the device needs community based indexing
+
+    # If we get a VTP version, it's *extremely* likely that the device needs
+    # community based indexing
     my $vtp = $cisco->vtp_version() || '0';
-    return ($vtp ne '0');
+    return $vtp ? 1 : 0;
+}
+
+sub eigrp_peers {
+    my $cisco = shift;
+
+    my $peers = $cisco->c_eigrp_peers()      || {};
+    my $types = $cisco->c_eigrp_peer_types() || {};
+
+    my %eigrp_peers;
+    foreach my $idx ( keys %$peers ) {
+        my $type = $types->{$idx};
+        next unless $type;
+        my $peer = $peers->{$idx};
+        next unless $peer;
+
+        my $ip = NetAddr::IP::Lite->new($peer);
+
+        if ($ip) {
+            $eigrp_peers{$idx} = $ip->addr;
+        }
+        elsif ( $type eq 'ipv4' ) {
+            $eigrp_peers{$idx} = SNMP::Info::munge_ip($peer);
+        }
+        next;
+    }
+    return \%eigrp_peers;
 }
 
 1;
@@ -159,7 +189,7 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $cisco = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
@@ -167,7 +197,7 @@ Max Baker
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $cisco->class();
