@@ -36,9 +36,9 @@ use SNMP::Info::Layer3;
 @SNMP::Info::Layer3::F5::ISA       = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::F5::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -165,8 +165,9 @@ sub i_type {
 
     my %i_type;
     foreach my $if ( keys %$idx ) {
-
-        $i_type{$if} = 'ethernetCsmacd';
+        $i_type{$if} =
+          ((exists $f5->{sess}->{UseEnums} and $f5->{sess}->{UseEnums})
+           ? 'ethernetCsmacd' : 6 );
     }
     return \%i_type;
 }
@@ -269,7 +270,7 @@ sub i_vlan_membership_untagged {
 
     my $i_vlan_membership = {};
     foreach my $iid ( keys %$tagged ) {
-        
+
         next unless $tagged->{$iid} eq 'false';
         # IID is length.vlan name index.length.interface index
         # Split out and use as the IID to get the VLAN ID and ifIndex
@@ -303,14 +304,14 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $f5 = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $f5->class();
@@ -321,7 +322,7 @@ Eric Miller
 Abstraction subclass for F5 network devices.
 
 For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
+after determining a more specific class using the method above.
 
  my $f5 = new SNMP::Info::Layer3::F5(...);
 
@@ -356,7 +357,7 @@ These are methods that return scalar value from SNMP
 =item $f5->model()
 
 Return (C<sysPlatformInfoMarketingName>), otherwise tries to reference
-$f5->id() to F<F5-BIGIP-COMMON-MIB>. 
+$f5->id() to F<F5-BIGIP-COMMON-MIB>.
 
 =item $f5->vendor()
 
@@ -419,7 +420,7 @@ IDs.
   Example:
   my $interfaces = $f5->interfaces();
   my $vlans      = $f5->i_vlan_membership();
-  
+
   foreach my $iid (sort keys %$interfaces) {
     my $port = $interfaces->{$iid};
     my $vlan = join(',', sort(@{$vlans->{$iid}}));
