@@ -38,9 +38,9 @@ use SNMP::Info::LLDP;
 @SNMP::Info::Layer3::Juniper::ISA       = qw/SNMP::Info::Layer3 SNMP::Info::LLDP  Exporter/;
 @SNMP::Info::Layer3::Juniper::EXPORT_OK = qw//;
 
-use vars qw/$VERSION $DEBUG %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, $DEBUG, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -49,36 +49,51 @@ $VERSION = '3.34';
     'JUNIPER-MIB'                 => 'jnxBoxAnatomy',
     'JUNIPER-VIRTUALCHASSIS-MIB'  => 'jnxVirtualChassisMemberTable',
     'JUNIPER-VLAN-MIB'            => 'jnxVlanMIBObjects',
+    'JUNIPER-L2ALD-MIB'           => 'jnxL2aldVlanFdbId',
 );
 
-%GLOBALS = ( %SNMP::Info::Layer3::GLOBALS, 
-	     %SNMP::Info::LLDP::GLOBALS,
-	     'serial'    => 'jnxBoxSerialNo.0',
-	     'mac'       => 'dot1dBaseBridgeAddress',
-	     'box_descr' => 'jnxBoxDescr'
-	     );
-
-%FUNCS = ( %SNMP::Info::Layer3::FUNCS, 
-	   %SNMP::Info::LLDP::FUNCS,
-	   
-	   # JUNIPER-VLAN-MIB::jnxExVlanTable
-	   'v_index'    => 'jnxExVlanTag',
-	   'v_type'     => 'jnxExVlanType',
-	   'v_name'     => 'jnxExVlanName',
-	   
-	   # JUNIPER-VLAN-MIB::jnxExVlanPortGroupTable
-	   'i_trunk'    => 'jnxExVlanPortAccessMode',
-	   
-	   # JUNPIER-MIB
-           'e_contents_type'   => 'jnxContentsType',
-           'e_containers_type' => 'jnxContainersType',
-           'e_hwver'           => 'jnxContentsRevision',
+%GLOBALS = (
+    %SNMP::Info::Layer3::GLOBALS,
+    %SNMP::Info::LLDP::GLOBALS,
+    'serial'    => 'jnxBoxSerialNo',
+    'mac'       => 'dot1dBaseBridgeAddress',
+    'box_descr' => 'jnxBoxDescr',
+    'version'   => 'jnxVirtualChassisMemberSWVersion',
+    'vc_model'  => 'jnxVirtualChassisMemberModel',
 );
 
-%MUNGE = ( %SNMP::Info::Layer3::MUNGE, 
-	   %SNMP::Info::LLDP::MUNGE,
-	   'e_containers_type' => \&SNMP::Info::munge_e_type,
-	   'e_contents_type' => \&SNMP::Info::munge_e_type,
+%FUNCS = (
+    %SNMP::Info::Layer3::FUNCS,
+    %SNMP::Info::LLDP::FUNCS,
+
+    # JUNIPER-VLAN-MIB::jnxExVlanPortGroupTable
+    'i_trunk' => 'jnxExVlanPortAccessMode',
+
+    # JUNIPER-MIB
+    'e_contents_type'   => 'jnxContentsType',
+    'e_containers_type' => 'jnxContainersType',
+    'e_hwver'           => 'jnxContentsRevision',
+
+    # JUNIPER-VLAN-MIB::jnxExVlanTable
+    'jnx_v_name'  => 'jnxExVlanName',
+    'jnx_v_index' => 'jnxExVlanTag',
+    'jnx_v_type'  => 'jnxExVlanType',
+
+    # JUNIPER-L2ALD-MIB::jnxL2aldVlanTable
+    # Used in Enhanced Layer 2 Software (ELS)
+    # replaces JUNIPER-VLAN-MIB::jnxExVlanTable
+    # in newer switches
+    'jnx_els_v_name'   => 'jnxL2aldVlanName',
+    'jnx_els_v_index'  => 'jnxL2aldVlanTag',
+    'jnx_els_v_type'   => 'jnxL2aldVlanType',
+    'jnx_els_v_fdb_id' => 'jnxL2aldVlanFdbId',
+);
+
+%MUNGE = (
+    %SNMP::Info::Layer3::MUNGE,
+    %SNMP::Info::LLDP::MUNGE,
+    'e_containers_type' => \&SNMP::Info::munge_e_type,
+    'e_contents_type'   => \&SNMP::Info::munge_e_type,
 );
 
 sub vendor {
@@ -91,11 +106,11 @@ sub os {
 
 sub layers {
     my $juniper = shift;
-    
+
     my $layers = $juniper->SUPER::layers();
-    # Some models don't report L2 properly 
+    # Some models don't report L2 properly
     my $macs   = $juniper->fw_mac();
-    
+
     if (keys %$macs) {
         my $l = substr $layers, 6, 1, "1";
     }
@@ -106,14 +121,20 @@ sub layers {
 sub os_ver {
     my $juniper = shift;
 
-    my $descr        = $juniper->description() || '';
-    my $lldp_descr   = $juniper->lldp_sysdesc() || '';
+    my $sys_descr  = $juniper->description()  || '';
+    my $lldp_descr = $juniper->lldp_sysdesc() || '';
 
-    if ( $descr =~ m/kernel JUNOS (\S+)/ ) {
-        return $1;
+    my $ver = $juniper->version() || '';
+    if (not $ver eq '')  {
+        return $ver;
     }
-    elsif ( $lldp_descr =~ m/version\s(\S+)\s/ ) {
-	return $1;
+    foreach my $descr ($sys_descr, $lldp_descr) {
+        if ( $descr =~ m/kernel JUNOS ([^,\s]+)/ ) {
+            return $1;
+        }
+        elsif ( $descr =~ m/version\s(\S+)\s/ ) {
+            return $1;
+        }
     }
     return;
 }
@@ -121,7 +142,13 @@ sub os_ver {
 sub model {
     my $l3 = shift;
     my $id = $l3->id();
+    # Query the junos device model.
+    my $mod = uc $l3->vc_model() || '';
 
+    if  (not $mod eq '') {
+        return $mod;
+    }
+    # Fallback to old method
     unless ( defined $id ) {
         print
             " SNMP::Info::Layer3::Juniper::model() - Device does not support sysObjectID\n"
@@ -154,42 +181,61 @@ sub i_trunk {
 
     foreach (keys %$access)
     {
-	my $old_key = $_;
-	m/^\d+\.(\d+)$/o;
-	my $new_key = $1;
-	$i_trunk{$new_key} = $access->{$old_key};
+	    my $old_key = $_;
+	    my $new_key = $old_key;
+        $new_key = $1 if m/^\d+\.(\d+)$/;
+	    $i_trunk{$new_key} = $access->{$old_key};
     }
 
     return \%i_trunk;
 }
 
+# Note: For overridden VLAN methods where we have to distinguish between newer
+# ELS and older models we try the newer methods first assuming they will be
+# more common to save on network queries. Short circuit operation depends on
+# leaf not present and snmp query returning undef
 sub qb_fdb_index {
-    my $juniper  = shift;
+    my $juniper = shift;
     my $partial = shift;
 
-    return $juniper->jnxExVlanTag($partial);
+    # Lots of indirection here
+    my $v_index = $juniper->jnx_els_v_index($partial);
+
+    if ( ref {} eq ref $v_index and scalar keys %$v_index ) {
+        my $fdb_index    = $juniper->jnx_els_v_fdb_id($partial);
+        my $qb_fdb_index = {};
+        for my $key ( keys(%$v_index) ) {
+            my $vlan = $v_index->{$key};
+            next unless defined $vlan;
+            my $fdb = $fdb_index->{$key};
+            next unless defined $fdb;
+            $qb_fdb_index->{$fdb} = $vlan;
+        }
+        return $qb_fdb_index;
+
+    }
+
+    $juniper->jnx_v_index($partial);
 }
 
-# 'v_type'     => 'jnxExVlanType',
+
 sub v_type {
     my $juniper = shift;
     my $partial = shift;
 
-    my $v_type  = $juniper->jnxExVlanType($partial);
-
-    return $v_type;
+    return $juniper->jnx_els_v_type($partial)
+        || $juniper->jnx_v_type($partial);
 }
 
-# 'v_index'    => 'jnxExVlanTag',
 sub v_index {
     my ($juniper) = shift;
     my ($partial) = shift;
 
-    my ($v_index)  = $juniper->jnxExVlanTag($partial);
-
-    return $v_index;
+    return $juniper->jnx_els_v_index($partial)
+        || $juniper->jnx_v_index($partial);
 }
 
+
 sub i_vlan {
     my $juniper = shift;
     my $partial = shift;
@@ -202,13 +248,15 @@ sub i_vlan {
         $partial = $r_index{$partial};
     }
 
-    my $v_index  = $juniper->jnxExVlanTag();
+    my $v_index  = $juniper->v_index();
     my $i_pvid   = $juniper->qb_i_vlan($partial) || {};
     my $i_vlan = {};
 
     foreach my $bport ( keys %$i_pvid ) {
         my $q_vlan  = $i_pvid->{$bport};
-	my $vlan    = $v_index->{$q_vlan};
+	    my $vlan    = $q_vlan;
+        # Use defined as check since VLAN can be zero
+        $vlan = $v_index->{$q_vlan} if defined $v_index->{$q_vlan};
         my $ifindex = $index->{$bport};
         unless ( defined $ifindex ) {
             print "  Port $bport has no bp_index mapping. Skipping.\n"
@@ -217,18 +265,23 @@ sub i_vlan {
         }
         $i_vlan->{$ifindex} = $vlan;
     }
-
     return $i_vlan;
 }
 
+sub v_name {
+    my $juniper = shift;
+
+    return $juniper->jnx_els_v_name() || $juniper->jnx_v_name();
+}
+
 # Index doesn't use VLAN ID, so override the HOA private method here to
-# correct the mapping 
+# correct the mapping
 sub _vlan_hoa {
     my $juniper = shift;
     my ( $v_ports, $partial ) = @_;
 
     my $index    = $juniper->bp_index();
-    my $v_index  = $juniper->jnxExVlanTag($partial);
+    my $v_index  = $juniper->v_index($partial);
 
     my $vlan_hoa = {};
     foreach my $idx ( keys %$v_ports ) {
@@ -256,6 +309,60 @@ sub _vlan_hoa {
     return $vlan_hoa;
 }
 
+# Older switches use RFC 4363 standard PortList definition, newer ELS switches
+# return an ASCII-encoded, comma separated string of port indexes - wow
+sub i_vlan_membership {
+    my $juniper = shift;
+    my $partial = shift;
+
+    # Use presence of JUNIPER-VLAN-MIB::jnxExVlanTag to indicate if we should
+    # treat as RFC 4363 standard PortList
+    my $old_index = $juniper->jnx_v_index();
+
+    if ( scalar keys %$old_index ) {
+        return $juniper->SUPER::i_vlan_membership($partial);
+    }
+
+    my $res;
+
+    # This isn't a PortList so use _raw to prevent munge
+    my $v_ports = $juniper->qb_cv_egress_raw($partial)
+        || $juniper->qb_v_egress_raw($partial);
+    my $bp_index = $juniper->bp_index();
+
+    foreach my $vlan ( keys %$v_ports ) {
+        my @bp_indexes = split /,/, $v_ports->{$vlan};
+        push @{ $res->{ $bp_index->{$_} } }, $vlan for @bp_indexes;
+    }
+    return $res;
+}
+
+sub i_vlan_membership_untagged {
+    my $juniper = shift;
+    my $partial = shift;
+
+    # Use presence of JUNIPER-VLAN-MIB::jnxExVlanTag to indicate if we should
+    # treat as RFC 4363 standard PortList
+    my $old_index = $juniper->jnx_v_index();
+
+    if ( scalar keys %$old_index ) {
+        return $juniper->SUPER::i_vlan_membership_untagged($partial);
+    }
+
+    my $res;
+
+    # This isn't a PortList so use _raw to prevent munge
+    my $v_ports = $juniper->qb_cv_untagged_raw($partial)
+        || $juniper->qb_v_untagged_raw($partial);
+    my $bp_index = $juniper->bp_index();
+
+    foreach my $vlan ( keys %$v_ports ) {
+        my @bp_indexes = split /,/, $v_ports->{$vlan};
+        push @{ $res->{ $bp_index->{$_} } }, $vlan for @bp_indexes;
+    }
+    return $res;
+}
+
 # Pseudo ENTITY-MIB methods
 
 # This class supports both virtual chassis (stackable) and physical chassis
@@ -266,7 +373,7 @@ sub _e_is_virtual {
     my $juniper = shift;
 
     my $v_test = $juniper->jnxVirtualChassisMemberRole() || {};
-    
+
     #If we are functioning as a stack someone should be master
     foreach my $iid ( keys %$v_test ) {
 	my $role = $v_test->{$iid};
@@ -278,24 +385,27 @@ sub _e_is_virtual {
 sub _e_virtual_index {
     my $juniper = shift;
 
-    my $containers = $juniper->jnxContainersWithin() || {};
+    my $containers = $juniper->jnxContainersWithin()         || {};
     my $members    = $juniper->jnxVirtualChassisMemberRole() || {};
-    
+
     my %v_index;
-    foreach my $key (keys %$containers) {
-	foreach my $member ( keys %$members ) {
-	    # Virtual chassis members start at zero
-	    $member++;
-	    # We will be duplicating and eliminating some keys,
-	    # but this is for the benefit of e_parent()
-	    my $index  = sprintf ("%02d", $key) . sprintf ("%02d", $member) . "0000";
-	    my $iid = "$key\.$member\.0\.0";
-	    $v_index{$iid} = $index;
-	}
-	unless ($containers->{$key}) {
-	    my $index = sprintf ("%02d", $key) . "000000";
-	    $v_index{$key} = $index;
-	}
+    foreach my $key ( keys %$containers ) {
+        foreach my $member ( keys %$members ) {
+
+            # Virtual chassis members start at zero
+            $member++;
+
+            # We will be duplicating and eliminating some keys,
+            # but this is for the benefit of e_parent()
+            my $index = sprintf( "%02d", $key )
+                . sprintf( "%02d", $member ) . "0000";
+            my $iid = "$key\.$member\.0\.0";
+            $v_index{$iid} = $index;
+        }
+        unless ( $containers->{$key} ) {
+            my $index = sprintf( "%02d", $key ) . "000000";
+            $v_index{$key} = $index;
+        }
     }
     return \%v_index;
 }
@@ -308,7 +418,7 @@ sub e_index {
     my $virtuals   = $juniper->_e_virtual_index() || {};
     my $is_virtual = $juniper->_e_is_virtual();
 
-    # Format into consistent integer format so that numeric sorting works     
+    # Format into consistent integer format so that numeric sorting works
     my %e_index;
     if ($is_virtual) {
 	foreach my $key ( keys %$virtuals ) {
@@ -323,7 +433,7 @@ sub e_index {
     foreach my $key ( keys %$contents ) {
 	$e_index{$key} = join( '', map { sprintf "%02d", $_ } split /\./, $key );
     }
- 
+
     return \%e_index;
 }
 
@@ -340,7 +450,7 @@ sub e_class {
 	
 	my $type      = $fru_type->{$iid} || 0;
 	my $container = $c_type->{$iid} || 0;
-	
+
         if ( $type =~ /power/i  ) {
             $e_class{$iid} = 'powerSupply';
         }
@@ -380,7 +490,7 @@ sub e_descr {
 	
 	my $content_descr   = $contents->{$iid} || 0;
 	my $container_descr = $containers->{$iid} || 0;
-	
+
 	if ($content_descr) {
 	    $e_descr{$iid} = $content_descr;
 	}
@@ -496,41 +606,46 @@ sub e_vendor {
 sub e_pos {
     my $juniper = shift;
 
-    # We could look at index levels, but his will work as well
+    # We could look at index levels, but this will work as well
     return $juniper->e_index();
 }
 
 sub e_parent {
     my $juniper = shift;
 
-    my $e_idx      = $juniper->e_index() || {};
-    my $c_within   = $juniper->jnxContainersWithin() || {};
-    my $e_descr    = $juniper->e_descr() || {};
+    my $e_idx    = $juniper->e_index()             || {};
+    my $c_within = $juniper->jnxContainersWithin() || {};
+    my $e_descr  = $juniper->e_descr()             || {};
     my $is_virtual = $juniper->_e_is_virtual();
-    
+
     my %e_parent;
     foreach my $iid ( keys %$e_idx ) {
         next unless $iid;
-	
-	my ($idx, $l1,$l2, $l3) = split /\./, $iid;
-	my $within = $c_within->{$idx};
-	my $descr  = $e_descr->{$iid};
-	
-        if ( !$is_virtual and ($iid =~ /^(\d+)\.\d+/) ) {
-            $e_parent{$iid} = sprintf ("%02d", $1) . "000000";
+
+        my ( $idx, $l1, $l2, $l3 ) = split /\./, $iid;
+        my $within = $c_within->{$idx};
+        my $descr  = $e_descr->{$iid};
+
+        if ( !$is_virtual and ( $iid =~ /^(\d+)\.\d+/ ) ) {
+            $e_parent{$iid} = sprintf( "%02d", $1 ) . "000000";
+        }
+        elsif ( $is_virtual
+            and ( $descr =~ /chassis/i )
+            and ( $iid =~ /^(\d+)\.(\d+)(\.0)+?/ ) )
+        {
+            $e_parent{$iid} = sprintf( "%02d", $1 ) . "000000";
+        }
+        elsif ( $is_virtual and ( $iid =~ /^(\d+)\.(\d+)(\.0)+?/ ) ) {
+            $e_parent{$iid}
+                = sprintf( "%02d", $within ) . sprintf( "%02d", $2 ) . "0000";
+        }
+        elsif ( $is_virtual and ( $iid =~ /^(\d+)\.(\d+)\.[1-9]+/ ) ) {
+            $e_parent{$iid}
+                = sprintf( "%02d", $1 ) . sprintf( "%02d", $2 ) . "0000";
+        }
+        elsif ( defined $within and $iid =~ /\d+/ ) {
+            $e_parent{$iid} = sprintf( "%02d", $within ) . "000000";
         }
-	elsif ( $is_virtual and ($descr =~ /chassis/i) and ($iid =~ /^(\d+)\.(\d+)(\.0)+?/) ) {
-	    $e_parent{$iid} = sprintf ("%02d", $1) . "000000";
-	}
-	elsif ( $is_virtual and ($iid =~ /^(\d+)\.(\d+)(\.0)+?/) ) {
-	    $e_parent{$iid} = sprintf ("%02d", $within) . sprintf ("%02d", $2) . "0000";
-	}
-	elsif ( $is_virtual and ($iid =~ /^(\d+)\.(\d+)\.[1-9]+/) ) {
-	    $e_parent{$iid} = sprintf ("%02d", $1) . sprintf ("%02d", $2) . "0000";
-	}
-	elsif ( defined $within and $iid =~ /\d+/ ) {
-            $e_parent{$iid} = sprintf ("%02d", $within) . "000000";
-	}
         else {
             next;
         }
@@ -538,6 +653,27 @@ sub e_parent {
     return \%e_parent;
 }
 
+sub peth_port_ifindex {
+    my $peth    = shift;
+    my $partial = shift;
+
+    my $peth_port_ifindex = {};
+    my $i_descr = $peth->i_description();
+
+    # Juniper doesn't have a translator, but the ports follow a standardized layout.
+    # Only the power status from the first member in a virtual chassis is reported.
+    foreach my $i ( keys %$i_descr ) {
+        # Juniper's port numbering is PHYS-FPC/PIC/PORT, only looking at PIC 0
+        if ($i_descr->{$i} =~ m/^(fe|ge|xe|et)-(\d+)\/(0)\/(\d+)$/) {
+            # Juniper port numbering begins at 0, but for PowerEthernet it begins at 1
+            my $mod = $2+1;
+            my $port = $4+1;
+            $peth_port_ifindex->{"$mod.$port"} = $i;
+        }
+    }
+    return $peth_port_ifindex;
+}
+
 1;
 __END__
 
@@ -551,14 +687,14 @@ Bill Fenner
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $juniper = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $juniper->class();
@@ -590,6 +726,8 @@ Subclass for Juniper Devices running JUNOS
 
 =item F<JUNIPER-VIRTUALCHASSIS-MIB>
 
+=item F<JUNIPER-L2ALD-MIB>
+
 =back
 
 =head2 Inherited Classes' MIBs
@@ -631,7 +769,7 @@ beginning.
 
 Returns serial number
 
-(C<jnxBoxSerialNo.0>)
+(C<jnxBoxSerialNo>)
 
 =item $juniper->mac()
 
@@ -644,7 +782,15 @@ to in a unique fashion.
 
 The name, model, or detailed description of the device.
 
-(C<jnxBoxDescr.0>)
+(C<jnxBoxDescr>)
+
+=item $juniper->version()
+
+(C<jnxVirtualChassisMemberSWVersion>)
+
+=item $juniper->vc_model()
+
+(C<jnxVirtualChassisMemberModel>)
 
 =back
 
@@ -665,19 +811,22 @@ to a hash.
 
 =item $juniper->qb_fdb_index()
 
-Returns reference to hash: key = VLAN ID, value = FDB ID.
+Returns reference to hash: key = FDB ID, value = VLAN ID.
 
 =item $juniper->v_index()
 
-(C<jnxExVlanTag>)
+Returns (C<jnxL2aldVlanTag>) or (C<jnxExVlanTag>) depending upon switch
+software version
 
 =item $juniper->v_name()
 
-(C<jnxExVlanName>)
+Returns (C<jnxL2aldVlanName>) or (C<jnxExVlanName>) depending upon switch
+software version
 
 =item $juniper->v_type()
 
-(C<jnxExVlanType>)
+Returns (C<jnxL2aldVlanType>) or (C<jnxExVlanType>) depending upon switch
+software version
 
 =item $juniper->i_trunk()
 
@@ -687,12 +836,30 @@ Returns reference to hash: key = VLAN ID, value = FDB ID.
 
 Returns a mapping between C<ifIndex> and the PVID or default VLAN.
 
+=item $juniper->i_vlan_membership()
+
+Returns reference to hash of arrays: key = C<ifIndex>, value = array of VLAN
+IDs.  These are the VLANs which are members of the egress list for the port.
+
+=item $juniper->i_vlan_membership_untagged()
+
+Returns reference to hash of arrays: key = C<ifIndex>, value = array of VLAN
+IDs.  These are the VLANs which are members of the untagged egress list for
+the port.
+
+=item $juniper->peth_port_ifindex()
+
+Returns reference to a hash: key= PowerEthernet MIB interface number,
+value = C<ifIndex>. As Juniper does not provide a mapping function,
+this does it manually.
+For example, ge-0/0/1 registers as PowerEthernet interface '1.2'
+
 =back
 
 =head2 Pseudo F<ENTITY-MIB> information
 
 These methods emulate F<ENTITY-MIB> Physical Table methods using
-F<JUNIPER-MIB> and F<JUNIPER-VIRTUALCHASSIS-MIB>. 
+F<JUNIPER-MIB> and F<JUNIPER-VIRTUALCHASSIS-MIB>.
 
 =over
 
