@@ -37,9 +37,9 @@ use SNMP::Info;
 @SNMP::Info::PowerEthernet::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::PowerEthernet::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.34';
+$VERSION = '3.68';
 
 %MIBS = ( 'POWER-ETHERNET-MIB' => 'pethPsePortDetectionStatus' );
 
@@ -73,7 +73,7 @@ sub peth_port_ifindex {
     my $partial = shift;
 
     my $peth_port_status = $peth->peth_port_status($partial);
-    my $peth_port_ifindex;
+    my $peth_port_ifindex = {};
 
     foreach my $i ( keys %$peth_port_status ) {
         my ( $module, $port ) = split( /\./, $i );
@@ -126,14 +126,14 @@ Bill Fenner
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $poe = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $poe->class();
